# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.cloud.asset_v1p1beta1.proto import (
    asset_service_pb2 as google_dot_cloud_dot_asset__v1p1beta1_dot_proto_dot_asset__service__pb2,
)


class AssetServiceStub(object):
    """Asset service definition.
  """

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.SearchAllResources = channel.unary_unary(
            "/google.cloud.asset.v1p1beta1.AssetService/SearchAllResources",
            request_serializer=google_dot_cloud_dot_asset__v1p1beta1_dot_proto_dot_asset__service__pb2.SearchAllResourcesRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_asset__v1p1beta1_dot_proto_dot_asset__service__pb2.SearchAllResourcesResponse.FromString,
        )
        self.SearchAllIamPolicies = channel.unary_unary(
            "/google.cloud.asset.v1p1beta1.AssetService/SearchAllIamPolicies",
            request_serializer=google_dot_cloud_dot_asset__v1p1beta1_dot_proto_dot_asset__service__pb2.SearchAllIamPoliciesRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_asset__v1p1beta1_dot_proto_dot_asset__service__pb2.SearchAllIamPoliciesResponse.FromString,
        )


class AssetServiceServicer(object):
    """Asset service definition.
  """

    def SearchAllResources(self, request, context):
        """Searches all the resources under a given accessible CRM scope
    (project/folder/organization). This RPC gives callers
    especially admins the ability to search all the resources under a scope,
    even if they don't have .get permission of all the resources. Callers
    should have cloud.assets.SearchAllResources permission on the requested
    scope, otherwise it will be rejected.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SearchAllIamPolicies(self, request, context):
        """Searches all the IAM policies under a given accessible CRM scope
    (project/folder/organization). This RPC gives callers
    especially admins the ability to search all the IAM policies under a scope,
    even if they don't have .getIamPolicy permission of all the IAM policies.
    Callers should have cloud.assets.SearchAllIamPolicies permission on the
    requested scope, otherwise it will be rejected.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_AssetServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "SearchAllResources": grpc.unary_unary_rpc_method_handler(
            servicer.SearchAllResources,
            request_deserializer=google_dot_cloud_dot_asset__v1p1beta1_dot_proto_dot_asset__service__pb2.SearchAllResourcesRequest.FromString,
            response_serializer=google_dot_cloud_dot_asset__v1p1beta1_dot_proto_dot_asset__service__pb2.SearchAllResourcesResponse.SerializeToString,
        ),
        "SearchAllIamPolicies": grpc.unary_unary_rpc_method_handler(
            servicer.SearchAllIamPolicies,
            request_deserializer=google_dot_cloud_dot_asset__v1p1beta1_dot_proto_dot_asset__service__pb2.SearchAllIamPoliciesRequest.FromString,
            response_serializer=google_dot_cloud_dot_asset__v1p1beta1_dot_proto_dot_asset__service__pb2.SearchAllIamPoliciesResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.cloud.asset.v1p1beta1.AssetService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/asset_v1beta1/proto/asset_service.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.asset_v1beta1.proto import (
    assets_pb2 as google_dot_cloud_dot_asset__v1beta1_dot_proto_dot_assets__pb2,
)
from google.longrunning import (
    operations_pb2 as google_dot_longrunning_dot_operations__pb2,
)
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/asset_v1beta1/proto/asset_service.proto",
    package="google.cloud.asset.v1beta1",
    syntax="proto3",
    serialized_options=b"\n\036com.google.cloud.asset.v1beta1B\021AssetServiceProtoP\001Z?google.golang.org/genproto/googleapis/cloud/asset/v1beta1;asset\252\002\032Google.Cloud.Asset.V1Beta1\312\002\032Google\\Cloud\\Asset\\V1beta1",
    serialized_pb=b'\n4google/cloud/asset_v1beta1/proto/asset_service.proto\x12\x1agoogle.cloud.asset.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a-google/cloud/asset_v1beta1/proto/assets.proto\x1a#google/longrunning/operations.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\x97\x02\n\x13\x45xportAssetsRequest\x12\x37\n\x06parent\x18\x01 \x01(\tB\'\xe0\x41\x02\xfa\x41!\x12\x1f\x63loudasset.googleapis.com/Asset\x12-\n\tread_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x61sset_types\x18\x03 \x03(\t\x12=\n\x0c\x63ontent_type\x18\x04 \x01(\x0e\x32\'.google.cloud.asset.v1beta1.ContentType\x12\x44\n\routput_config\x18\x05 \x01(\x0b\x32(.google.cloud.asset.v1beta1.OutputConfigB\x03\xe0\x41\x02"\x86\x01\n\x14\x45xportAssetsResponse\x12-\n\tread_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\routput_config\x18\x02 \x01(\x0b\x32(.google.cloud.asset.v1beta1.OutputConfig"\xf7\x01\n\x1c\x42\x61tchGetAssetsHistoryRequest\x12\x37\n\x06parent\x18\x01 \x01(\tB\'\xe0\x41\x02\xfa\x41!\x12\x1f\x63loudasset.googleapis.com/Asset\x12\x13\n\x0b\x61sset_names\x18\x02 \x03(\t\x12\x42\n\x0c\x63ontent_type\x18\x03 \x01(\x0e\x32\'.google.cloud.asset.v1beta1.ContentTypeB\x03\xe0\x41\x01\x12\x45\n\x10read_time_window\x18\x04 \x01(\x0b\x32&.google.cloud.asset.v1beta1.TimeWindowB\x03\xe0\x41\x01"Z\n\x1d\x42\x61tchGetAssetsHistoryResponse\x12\x39\n\x06\x61ssets\x18\x01 \x03(\x0b\x32).google.cloud.asset.v1beta1.TemporalAsset"d\n\x0cOutputConfig\x12\x45\n\x0fgcs_destination\x18\x01 \x01(\x0b\x32*.google.cloud.asset.v1beta1.GcsDestinationH\x00\x42\r\n\x0b\x64\x65stination"C\n\x0eGcsDestination\x12\r\n\x03uri\x18\x01 \x01(\tH\x00\x12\x14\n\nuri_prefix\x18\x02 \x01(\tH\x00\x42\x0c\n\nobject_uri*I\n\x0b\x43ontentType\x12\x1c\n\x18\x43ONTENT_TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08RESOURCE\x10\x01\x12\x0e\n\nIAM_POLICY\x10\x02\x32\xc4\x05\n\x0c\x41ssetService\x12\xde\x02\n\x0c\x45xportAssets\x12/.google.cloud.asset.v1beta1.ExportAssetsRequest\x1a\x1d.google.longrunning.Operation"\xfd\x01\x82\xd3\xe4\x93\x02\x92\x01")/v1beta1/{parent=projects/*}:exportAssets:\x01*Z-"(/v1beta1/{parent=folders/*}:exportAssets:\x01*Z3"./v1beta1/{parent=organizations/*}:exportAssets:\x01*\xca\x41\x61\n/google.cloud.asset.v1beta1.ExportAssetsResponse\x12.google.cloud.asset.v1beta1.ExportAssetsRequest\x12\x83\x02\n\x15\x42\x61tchGetAssetsHistory\x12\x38.google.cloud.asset.v1beta1.BatchGetAssetsHistoryRequest\x1a\x39.google.cloud.asset.v1beta1.BatchGetAssetsHistoryResponse"u\x82\xd3\xe4\x93\x02o\x12\x32/v1beta1/{parent=projects/*}:batchGetAssetsHistoryZ9\x12\x37/v1beta1/{parent=organizations/*}:batchGetAssetsHistory\x1aM\xca\x41\x19\x63loudasset.googleapis.com\xd2\x41.https://www.googleapis.com/auth/cloud-platformB\xb0\x01\n\x1e\x63om.google.cloud.asset.v1beta1B\x11\x41ssetServiceProtoP\x01Z?google.golang.org/genproto/googleapis/cloud/asset/v1beta1;asset\xaa\x02\x1aGoogle.Cloud.Asset.V1Beta1\xca\x02\x1aGoogle\\Cloud\\Asset\\V1beta1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_asset__v1beta1_dot_proto_dot_assets__pb2.DESCRIPTOR,
        google_dot_longrunning_dot_operations__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
    ],
)

_CONTENTTYPE = _descriptor.EnumDescriptor(
    name="ContentType",
    full_name="google.cloud.asset.v1beta1.ContentType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="CONTENT_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="RESOURCE", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="IAM_POLICY", index=2, number=2, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1248,
    serialized_end=1321,
)
_sym_db.RegisterEnumDescriptor(_CONTENTTYPE)

ContentType = enum_type_wrapper.EnumTypeWrapper(_CONTENTTYPE)
CONTENT_TYPE_UNSPECIFIED = 0
RESOURCE = 1
IAM_POLICY = 2


_EXPORTASSETSREQUEST = _descriptor.Descriptor(
    name="ExportAssetsRequest",
    full_name="google.cloud.asset.v1beta1.ExportAssetsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.asset.v1beta1.ExportAssetsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A!\022\037cloudasset.googleapis.com/Asset",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="read_time",
            full_name="google.cloud.asset.v1beta1.ExportAssetsRequest.read_time",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="asset_types",
            full_name="google.cloud.asset.v1beta1.ExportAssetsRequest.asset_types",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="content_type",
            full_name="google.cloud.asset.v1beta1.ExportAssetsRequest.content_type",
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="output_config",
            full_name="google.cloud.asset.v1beta1.ExportAssetsRequest.output_config",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=317,
    serialized_end=596,
)


_EXPORTASSETSRESPONSE = _descriptor.Descriptor(
    name="ExportAssetsResponse",
    full_name="google.cloud.asset.v1beta1.ExportAssetsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="read_time",
            full_name="google.cloud.asset.v1beta1.ExportAssetsResponse.read_time",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="output_config",
            full_name="google.cloud.asset.v1beta1.ExportAssetsResponse.output_config",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=599,
    serialized_end=733,
)


_BATCHGETASSETSHISTORYREQUEST = _descriptor.Descriptor(
    name="BatchGetAssetsHistoryRequest",
    full_name="google.cloud.asset.v1beta1.BatchGetAssetsHistoryRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.asset.v1beta1.BatchGetAssetsHistoryRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A!\022\037cloudasset.googleapis.com/Asset",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="asset_names",
            full_name="google.cloud.asset.v1beta1.BatchGetAssetsHistoryRequest.asset_names",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="content_type",
            full_name="google.cloud.asset.v1beta1.BatchGetAssetsHistoryRequest.content_type",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="read_time_window",
            full_name="google.cloud.asset.v1beta1.BatchGetAssetsHistoryRequest.read_time_window",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=736,
    serialized_end=983,
)


_BATCHGETASSETSHISTORYRESPONSE = _descriptor.Descriptor(
    name="BatchGetAssetsHistoryResponse",
    full_name="google.cloud.asset.v1beta1.BatchGetAssetsHistoryResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="assets",
            full_name="google.cloud.asset.v1beta1.BatchGetAssetsHistoryResponse.assets",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=985,
    serialized_end=1075,
)


_OUTPUTCONFIG = _descriptor.Descriptor(
    name="OutputConfig",
    full_name="google.cloud.asset.v1beta1.OutputConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="gcs_destination",
            full_name="google.cloud.asset.v1beta1.OutputConfig.gcs_destination",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="destination",
            full_name="google.cloud.asset.v1beta1.OutputConfig.destination",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=1077,
    serialized_end=1177,
)


_GCSDESTINATION = _descriptor.Descriptor(
    name="GcsDestination",
    full_name="google.cloud.asset.v1beta1.GcsDestination",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="uri",
            full_name="google.cloud.asset.v1beta1.GcsDestination.uri",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="uri_prefix",
            full_name="google.cloud.asset.v1beta1.GcsDestination.uri_prefix",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="object_uri",
            full_name="google.cloud.asset.v1beta1.GcsDestination.object_uri",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=1179,
    serialized_end=1246,
)

_EXPORTASSETSREQUEST.fields_by_name[
    "read_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPORTASSETSREQUEST.fields_by_name["content_type"].enum_type = _CONTENTTYPE
_EXPORTASSETSREQUEST.fields_by_name["output_config"].message_type = _OUTPUTCONFIG
_EXPORTASSETSRESPONSE.fields_by_name[
    "read_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPORTASSETSRESPONSE.fields_by_name["output_config"].message_type = _OUTPUTCONFIG
_BATCHGETASSETSHISTORYREQUEST.fields_by_name["content_type"].enum_type = _CONTENTTYPE
_BATCHGETASSETSHISTORYREQUEST.fields_by_name[
    "read_time_window"
].message_type = (
    google_dot_cloud_dot_asset__v1beta1_dot_proto_dot_assets__pb2._TIMEWINDOW
)
_BATCHGETASSETSHISTORYRESPONSE.fields_by_name[
    "assets"
].message_type = (
    google_dot_cloud_dot_asset__v1beta1_dot_proto_dot_assets__pb2._TEMPORALASSET
)
_OUTPUTCONFIG.fields_by_name["gcs_destination"].message_type = _GCSDESTINATION
_OUTPUTCONFIG.oneofs_by_name["destination"].fields.append(
    _OUTPUTCONFIG.fields_by_name["gcs_destination"]
)
_OUTPUTCONFIG.fields_by_name[
    "gcs_destination"
].containing_oneof = _OUTPUTCONFIG.oneofs_by_name["destination"]
_GCSDESTINATION.oneofs_by_name["object_uri"].fields.append(
    _GCSDESTINATION.fields_by_name["uri"]
)
_GCSDESTINATION.fields_by_name["uri"].containing_oneof = _GCSDESTINATION.oneofs_by_name[
    "object_uri"
]
_GCSDESTINATION.oneofs_by_name["object_uri"].fields.append(
    _GCSDESTINATION.fields_by_name["uri_prefix"]
)
_GCSDESTINATION.fields_by_name[
    "uri_prefix"
].containing_oneof = _GCSDESTINATION.oneofs_by_name["object_uri"]
DESCRIPTOR.message_types_by_name["ExportAssetsRequest"] = _EXPORTASSETSREQUEST
DESCRIPTOR.message_types_by_name["ExportAssetsResponse"] = _EXPORTASSETSRESPONSE
DESCRIPTOR.message_types_by_name[
    "BatchGetAssetsHistoryRequest"
] = _BATCHGETASSETSHISTORYREQUEST
DESCRIPTOR.message_types_by_name[
    "BatchGetAssetsHistoryResponse"
] = _BATCHGETASSETSHISTORYRESPONSE
DESCRIPTOR.message_types_by_name["OutputConfig"] = _OUTPUTCONFIG
DESCRIPTOR.message_types_by_name["GcsDestination"] = _GCSDESTINATION
DESCRIPTOR.enum_types_by_name["ContentType"] = _CONTENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExportAssetsRequest = _reflection.GeneratedProtocolMessageType(
    "ExportAssetsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXPORTASSETSREQUEST,
        "__module__": "google.cloud.asset_v1beta1.proto.asset_service_pb2",
        "__doc__": """Export asset request.
  
  
  Attributes:
      parent:
          Required. The relative name of the root asset. This can only
          be an organization number (such as “organizations/123”), a
          project ID (such as “projects/my-project-id”), a project
          number (such as “projects/12345”), or a folder number (such as
          “folders/123”).
      read_time:
          Timestamp to take an asset snapshot. This can only be set to a
          timestamp between 2018-10-02 UTC (inclusive) and the current
          time. If not specified, the current time will be used. Due to
          delays in resource data collection and indexing, there is a
          volatile window during which running the same query may get
          different results.
      asset_types:
          A list of asset types of which to take a snapshot for. For
          example: “google.compute.Disk”. If specified, only matching
          assets will be returned. See `Introduction to Cloud Asset
          Inventory <https://cloud.google.com/resource-
          manager/docs/cloud-asset-inventory/overview>`__ for all
          supported asset types.
      content_type:
          Asset content type. If not specified, no content but the asset
          name will be returned.
      output_config:
          Required. Output configuration indicating where the results
          will be output to. All results will be in newline delimited
          JSON format.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1beta1.ExportAssetsRequest)
    },
)
_sym_db.RegisterMessage(ExportAssetsRequest)

ExportAssetsResponse = _reflection.GeneratedProtocolMessageType(
    "ExportAssetsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXPORTASSETSRESPONSE,
        "__module__": "google.cloud.asset_v1beta1.proto.asset_service_pb2",
        "__doc__": """The export asset response. This message is returned by the
  [google.longrunning.Operations.GetOperation][google.longrunning.Operations.GetOperation]
  method in the returned
  [google.longrunning.Operation.response][google.longrunning.Operation.response]
  field.
  
  
  Attributes:
      read_time:
          Time the snapshot was taken.
      output_config:
          Output configuration indicating where the results were output
          to. All results are in JSON format.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1beta1.ExportAssetsResponse)
    },
)
_sym_db.RegisterMessage(ExportAssetsResponse)

BatchGetAssetsHistoryRequest = _reflection.GeneratedProtocolMessageType(
    "BatchGetAssetsHistoryRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _BATCHGETASSETSHISTORYREQUEST,
        "__module__": "google.cloud.asset_v1beta1.proto.asset_service_pb2",
        "__doc__": """Batch get assets history request.
  
  
  Attributes:
      parent:
          Required. The relative name of the root asset. It can only be
          an organization number (such as “organizations/123”), a
          project ID (such as “projects/my-project-id”)“, or a project
          number (such as”projects/12345").
      asset_names:
          A list of the full names of the assets. For example: ``//compu
          te.googleapis.com/projects/my_project_123/zones/zone1/instance
          s/instance1``. See `Resource Names <https://cloud.google.com/a
          pis/design/resource_names#full_resource_name>`__ for more
          info.  The request becomes a no-op if the asset name list is
          empty, and the max size of the asset name list is 100 in one
          request.
      content_type:
          Optional. The content type.
      read_time_window:
          Optional. The time window for the asset history. Both
          start_time and end_time are optional and if set, it must be
          after 2018-10-02 UTC. If end_time is not set, it is default to
          current timestamp. If start_time is not set, the snapshot of
          the assets at end_time will be returned. The returned results
          contain all temporal assets whose time window overlap with
          read_time_window.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1beta1.BatchGetAssetsHistoryRequest)
    },
)
_sym_db.RegisterMessage(BatchGetAssetsHistoryRequest)

BatchGetAssetsHistoryResponse = _reflection.GeneratedProtocolMessageType(
    "BatchGetAssetsHistoryResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _BATCHGETASSETSHISTORYRESPONSE,
        "__module__": "google.cloud.asset_v1beta1.proto.asset_service_pb2",
        "__doc__": """Batch get assets history response.
  
  
  Attributes:
      assets:
          A list of assets with valid time windows.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1beta1.BatchGetAssetsHistoryResponse)
    },
)
_sym_db.RegisterMessage(BatchGetAssetsHistoryResponse)

OutputConfig = _reflection.GeneratedProtocolMessageType(
    "OutputConfig",
    (_message.Message,),
    {
        "DESCRIPTOR": _OUTPUTCONFIG,
        "__module__": "google.cloud.asset_v1beta1.proto.asset_service_pb2",
        "__doc__": """Output configuration for export assets destination.
  
  
  Attributes:
      destination:
          Asset export destination.
      gcs_destination:
          Destination on Cloud Storage.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1beta1.OutputConfig)
    },
)
_sym_db.RegisterMessage(OutputConfig)

GcsDestination = _reflection.GeneratedProtocolMessageType(
    "GcsDestination",
    (_message.Message,),
    {
        "DESCRIPTOR": _GCSDESTINATION,
        "__module__": "google.cloud.asset_v1beta1.proto.asset_service_pb2",
        "__doc__": """A Cloud Storage location.
  
  
  Attributes:
      object_uri:
          Required.
      uri:
          The uri of the Cloud Storage object. It’s the same uri that is
          used by gsutil. For example: “gs://bucket_name/object_name”.
          See `Viewing and Editing Object Metadata
          <https://cloud.google.com/storage/docs/viewing-editing-
          metadata>`__ for more information.
      uri_prefix:
          The uri prefix of all generated Cloud Storage objects. For
          example: “gs://bucket_name/object_name_prefix”. Each object
          uri is in format: “gs://bucket_name/object_name_prefix// and
          only contains assets for that type. starts from 0. For example
          :”gs://bucket_name/object_name_prefix/google.compute.disk/0"
          is the first shard of output objects containing all
          google.compute.disk assets. An INVALID_ARGUMENT error will be
          returned if file with the same name
          “gs://bucket_name/object_name_prefix” already exists.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1beta1.GcsDestination)
    },
)
_sym_db.RegisterMessage(GcsDestination)


DESCRIPTOR._options = None
_EXPORTASSETSREQUEST.fields_by_name["parent"]._options = None
_EXPORTASSETSREQUEST.fields_by_name["output_config"]._options = None
_BATCHGETASSETSHISTORYREQUEST.fields_by_name["parent"]._options = None
_BATCHGETASSETSHISTORYREQUEST.fields_by_name["content_type"]._options = None
_BATCHGETASSETSHISTORYREQUEST.fields_by_name["read_time_window"]._options = None

_ASSETSERVICE = _descriptor.ServiceDescriptor(
    name="AssetService",
    full_name="google.cloud.asset.v1beta1.AssetService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\312A\031cloudasset.googleapis.com\322A.https://www.googleapis.com/auth/cloud-platform",
    serialized_start=1324,
    serialized_end=2032,
    methods=[
        _descriptor.MethodDescriptor(
            name="ExportAssets",
            full_name="google.cloud.asset.v1beta1.AssetService.ExportAssets",
            index=0,
            containing_service=None,
            input_type=_EXPORTASSETSREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=b'\202\323\344\223\002\222\001")/v1beta1/{parent=projects/*}:exportAssets:\001*Z-"(/v1beta1/{parent=folders/*}:exportAssets:\001*Z3"./v1beta1/{parent=organizations/*}:exportAssets:\001*\312Aa\n/google.cloud.asset.v1beta1.ExportAssetsResponse\022.google.cloud.asset.v1beta1.ExportAssetsRequest',
        ),
        _descriptor.MethodDescriptor(
            name="BatchGetAssetsHistory",
            full_name="google.cloud.asset.v1beta1.AssetService.BatchGetAssetsHistory",
            index=1,
            containing_service=None,
            input_type=_BATCHGETASSETSHISTORYREQUEST,
            output_type=_BATCHGETASSETSHISTORYRESPONSE,
            serialized_options=b"\202\323\344\223\002o\0222/v1beta1/{parent=projects/*}:batchGetAssetsHistoryZ9\0227/v1beta1/{parent=organizations/*}:batchGetAssetsHistory",
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_ASSETSERVICE)

DESCRIPTOR.services_by_name["AssetService"] = _ASSETSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# flake8: noqa

import os
import pytest

from google.api_core import exceptions
from google.cloud import asset_v1
from google.cloud.asset_v1 import enums
from test_utils.vpcsc_config import vpcsc_config

_VPCSC_PROHIBITED_MESSAGE = "Request is prohibited by organization's policy"


@pytest.fixture
def client():
    return asset_v1.AssetServiceClient()


@pytest.fixture
def output_config():
    bucket_uri = "gs:{}/g-c-p-export-test".format(vpcsc_config.bucket_outside)
    output_config = {"gcsDestination": {"uri": bucket_uri}}


@pytest.fixture
def parent_inside():
    return "projects/" + vpcsc_config.project_inside


@pytest.fixture
def parent_outside():
    return "projects/" + vpcsc_config.project_outside


@vpcsc_config.skip_unless_inside_vpcsc
def test_export_assets_inside(client, output_config, parent_inside):
    with pytest.raises(exceptions.InvalidArgument):
        client.export_assets(parent_inside, output_config)


@vpcsc_config.skip_unless_inside_vpcsc
def test_export_assets_outside(client, output_config, parent_outside):
    with pytest.raises(exceptions.PermissionDenied) as exc:
        client.export_assets(parent_outside, output_config)

    assert _VPCSC_PROHIBITED_MESSAGE in exc.value.message


@vpcsc_config.skip_unless_inside_vpcsc
def test_batch_get_assets_history_inside(client, parent_inside):
    read_time_window = {}
    client.batch_get_assets_history(
        parent_inside,
        content_type=enums.ContentType.CONTENT_TYPE_UNSPECIFIED,
        read_time_window={},
    )


@vpcsc_config.skip_unless_inside_vpcsc
def test_batch_get_assets_history_outside(client, parent_outside):
    content_type = enums.ContentType.CONTENT_TYPE_UNSPECIFIED
    read_time_window = {}
    with pytest.raises(exceptions.PermissionDenied) as exc:
        client.batch_get_assets_history(
            parent_outside,
            content_type=enums.ContentType.CONTENT_TYPE_UNSPECIFIED,
            read_time_window={},
        )

    assert _VPCSC_PROHIBITED_MESSAGE in exc.value.message



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/asset_v1/proto/assets.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.orgpolicy.v1 import (
    orgpolicy_pb2 as google_dot_cloud_dot_orgpolicy_dot_v1_dot_orgpolicy__pb2,
)
from google.iam.v1 import iam_policy_pb2 as google_dot_iam_dot_v1_dot_policy__pb2
from google.identity.accesscontextmanager.v1 import (
    access_level_pb2 as google_dot_identity_dot_accesscontextmanager_dot_v1_dot_access__level__pb2,
)
from google.identity.accesscontextmanager.v1 import (
    access_policy_pb2 as google_dot_identity_dot_accesscontextmanager_dot_v1_dot_access__policy__pb2,
)
from google.identity.accesscontextmanager.v1 import (
    service_perimeter_pb2 as google_dot_identity_dot_accesscontextmanager_dot_v1_dot_service__perimeter__pb2,
)
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/asset_v1/proto/assets.proto",
    package="google.cloud.asset.v1",
    syntax="proto3",
    serialized_options=b"\n\031com.google.cloud.asset.v1B\nAssetProtoP\001Z:google.golang.org/genproto/googleapis/cloud/asset/v1;asset\370\001\001\252\002\025Google.Cloud.Asset.V1\312\002\025Google\\Cloud\\Asset\\V1",
    serialized_pb=b'\n(google/cloud/asset_v1/proto/assets.proto\x12\x15google.cloud.asset.v1\x1a\x19google/api/resource.proto\x1a)google/cloud/orgpolicy/v1/orgpolicy.proto\x1a\x1agoogle/iam/v1/policy.proto\x1a:google/identity/accesscontextmanager/v1/access_level.proto\x1a;google/identity/accesscontextmanager/v1/access_policy.proto\x1a?google/identity/accesscontextmanager/v1/service_perimeter.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/api/annotations.proto"\x80\x01\n\rTemporalAsset\x12\x31\n\x06window\x18\x01 \x01(\x0b\x32!.google.cloud.asset.v1.TimeWindow\x12\x0f\n\x07\x64\x65leted\x18\x02 \x01(\x08\x12+\n\x05\x61sset\x18\x03 \x01(\x0b\x32\x1c.google.cloud.asset.v1.Asset"j\n\nTimeWindow\x12.\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp"\x89\x04\n\x05\x41sset\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nasset_type\x18\x02 \x01(\t\x12\x31\n\x08resource\x18\x03 \x01(\x0b\x32\x1f.google.cloud.asset.v1.Resource\x12)\n\niam_policy\x18\x04 \x01(\x0b\x32\x15.google.iam.v1.Policy\x12\x35\n\norg_policy\x18\x06 \x03(\x0b\x32!.google.cloud.orgpolicy.v1.Policy\x12N\n\raccess_policy\x18\x07 \x01(\x0b\x32\x35.google.identity.accesscontextmanager.v1.AccessPolicyH\x00\x12L\n\x0c\x61\x63\x63\x65ss_level\x18\x08 \x01(\x0b\x32\x34.google.identity.accesscontextmanager.v1.AccessLevelH\x00\x12V\n\x11service_perimeter\x18\t \x01(\x0b\x32\x39.google.identity.accesscontextmanager.v1.ServicePerimeterH\x00\x12\x11\n\tancestors\x18\n \x03(\t:\'\xea\x41$\n\x1f\x63loudasset.googleapis.com/Asset\x12\x01*B\x17\n\x15\x61\x63\x63\x65ss_context_policy"\xa0\x01\n\x08Resource\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x1e\n\x16\x64iscovery_document_uri\x18\x02 \x01(\t\x12\x16\n\x0e\x64iscovery_name\x18\x03 \x01(\t\x12\x14\n\x0cresource_url\x18\x04 \x01(\t\x12\x0e\n\x06parent\x18\x05 \x01(\t\x12%\n\x04\x64\x61ta\x18\x06 \x01(\x0b\x32\x17.google.protobuf.StructB\x98\x01\n\x19\x63om.google.cloud.asset.v1B\nAssetProtoP\x01Z:google.golang.org/genproto/googleapis/cloud/asset/v1;asset\xf8\x01\x01\xaa\x02\x15Google.Cloud.Asset.V1\xca\x02\x15Google\\Cloud\\Asset\\V1b\x06proto3',
    dependencies=[
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_orgpolicy_dot_v1_dot_orgpolicy__pb2.DESCRIPTOR,
        google_dot_iam_dot_v1_dot_policy__pb2.DESCRIPTOR,
        google_dot_identity_dot_accesscontextmanager_dot_v1_dot_access__level__pb2.DESCRIPTOR,
        google_dot_identity_dot_accesscontextmanager_dot_v1_dot_access__policy__pb2.DESCRIPTOR,
        google_dot_identity_dot_accesscontextmanager_dot_v1_dot_service__perimeter__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_any__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
    ],
)


_TEMPORALASSET = _descriptor.Descriptor(
    name="TemporalAsset",
    full_name="google.cloud.asset.v1.TemporalAsset",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="window",
            full_name="google.cloud.asset.v1.TemporalAsset.window",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="deleted",
            full_name="google.cloud.asset.v1.TemporalAsset.deleted",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="asset",
            full_name="google.cloud.asset.v1.TemporalAsset.asset",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=472,
    serialized_end=600,
)


_TIMEWINDOW = _descriptor.Descriptor(
    name="TimeWindow",
    full_name="google.cloud.asset.v1.TimeWindow",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="start_time",
            full_name="google.cloud.asset.v1.TimeWindow.start_time",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="end_time",
            full_name="google.cloud.asset.v1.TimeWindow.end_time",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=602,
    serialized_end=708,
)


_ASSET = _descriptor.Descriptor(
    name="Asset",
    full_name="google.cloud.asset.v1.Asset",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.asset.v1.Asset.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="asset_type",
            full_name="google.cloud.asset.v1.Asset.asset_type",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="resource",
            full_name="google.cloud.asset.v1.Asset.resource",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="iam_policy",
            full_name="google.cloud.asset.v1.Asset.iam_policy",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="org_policy",
            full_name="google.cloud.asset.v1.Asset.org_policy",
            index=4,
            number=6,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="access_policy",
            full_name="google.cloud.asset.v1.Asset.access_policy",
            index=5,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="access_level",
            full_name="google.cloud.asset.v1.Asset.access_level",
            index=6,
            number=8,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="service_perimeter",
            full_name="google.cloud.asset.v1.Asset.service_perimeter",
            index=7,
            number=9,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="ancestors",
            full_name="google.cloud.asset.v1.Asset.ancestors",
            index=8,
            number=10,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"\352A$\n\037cloudasset.googleapis.com/Asset\022\001*",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="access_context_policy",
            full_name="google.cloud.asset.v1.Asset.access_context_policy",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=711,
    serialized_end=1232,
)


_RESOURCE = _descriptor.Descriptor(
    name="Resource",
    full_name="google.cloud.asset.v1.Resource",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="version",
            full_name="google.cloud.asset.v1.Resource.version",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="discovery_document_uri",
            full_name="google.cloud.asset.v1.Resource.discovery_document_uri",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="discovery_name",
            full_name="google.cloud.asset.v1.Resource.discovery_name",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="resource_url",
            full_name="google.cloud.asset.v1.Resource.resource_url",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.asset.v1.Resource.parent",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="data",
            full_name="google.cloud.asset.v1.Resource.data",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1235,
    serialized_end=1395,
)

_TEMPORALASSET.fields_by_name["window"].message_type = _TIMEWINDOW
_TEMPORALASSET.fields_by_name["asset"].message_type = _ASSET
_TIMEWINDOW.fields_by_name[
    "start_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TIMEWINDOW.fields_by_name[
    "end_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ASSET.fields_by_name["resource"].message_type = _RESOURCE
_ASSET.fields_by_name[
    "iam_policy"
].message_type = (
    google_dot_iam_dot_v1_dot_policy__pb2.google_dot_iam_dot_v1_dot_policy__pb2._POLICY
)
_ASSET.fields_by_name[
    "org_policy"
].message_type = google_dot_cloud_dot_orgpolicy_dot_v1_dot_orgpolicy__pb2._POLICY
_ASSET.fields_by_name[
    "access_policy"
].message_type = (
    google_dot_identity_dot_accesscontextmanager_dot_v1_dot_access__policy__pb2._ACCESSPOLICY
)
_ASSET.fields_by_name[
    "access_level"
].message_type = (
    google_dot_identity_dot_accesscontextmanager_dot_v1_dot_access__level__pb2._ACCESSLEVEL
)
_ASSET.fields_by_name[
    "service_perimeter"
].message_type = (
    google_dot_identity_dot_accesscontextmanager_dot_v1_dot_service__perimeter__pb2._SERVICEPERIMETER
)
_ASSET.oneofs_by_name["access_context_policy"].fields.append(
    _ASSET.fields_by_name["access_policy"]
)
_ASSET.fields_by_name["access_policy"].containing_oneof = _ASSET.oneofs_by_name[
    "access_context_policy"
]
_ASSET.oneofs_by_name["access_context_policy"].fields.append(
    _ASSET.fields_by_name["access_level"]
)
_ASSET.fields_by_name["access_level"].containing_oneof = _ASSET.oneofs_by_name[
    "access_context_policy"
]
_ASSET.oneofs_by_name["access_context_policy"].fields.append(
    _ASSET.fields_by_name["service_perimeter"]
)
_ASSET.fields_by_name["service_perimeter"].containing_oneof = _ASSET.oneofs_by_name[
    "access_context_policy"
]
_RESOURCE.fields_by_name[
    "data"
].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
DESCRIPTOR.message_types_by_name["TemporalAsset"] = _TEMPORALASSET
DESCRIPTOR.message_types_by_name["TimeWindow"] = _TIMEWINDOW
DESCRIPTOR.message_types_by_name["Asset"] = _ASSET
DESCRIPTOR.message_types_by_name["Resource"] = _RESOURCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TemporalAsset = _reflection.GeneratedProtocolMessageType(
    "TemporalAsset",
    (_message.Message,),
    {
        "DESCRIPTOR": _TEMPORALASSET,
        "__module__": "google.cloud.asset_v1.proto.assets_pb2",
        "__doc__": """An asset in Google Cloud and its temporal metadata, including the time
  window when it was observed and its status during that window.
  
  
  Attributes:
      window:
          The time window when the asset data and state was observed.
      deleted:
          Whether the asset has been deleted or not.
      asset:
          An asset in Google Cloud.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1.TemporalAsset)
    },
)
_sym_db.RegisterMessage(TemporalAsset)

TimeWindow = _reflection.GeneratedProtocolMessageType(
    "TimeWindow",
    (_message.Message,),
    {
        "DESCRIPTOR": _TIMEWINDOW,
        "__module__": "google.cloud.asset_v1.proto.assets_pb2",
        "__doc__": """A time window specified by its “start_time” and
  “end_time”.
  
  
  Attributes:
      start_time:
          Start time of the time window (exclusive).
      end_time:
          End time of the time window (inclusive). If not specified, the
          current timestamp is used instead.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1.TimeWindow)
    },
)
_sym_db.RegisterMessage(TimeWindow)

Asset = _reflection.GeneratedProtocolMessageType(
    "Asset",
    (_message.Message,),
    {
        "DESCRIPTOR": _ASSET,
        "__module__": "google.cloud.asset_v1.proto.assets_pb2",
        "__doc__": """An asset in Google Cloud. An asset can be any resource in
  the Google Cloud `resource
  hierarchy <https://cloud.google.com/resource-manager/docs/cloud-platform-resource-hierarchy>`__,
  a resource outside the Google Cloud resource hierarchy (such as Google
  Kubernetes Engine clusters and objects), or a Cloud IAM policy.
  
  
  Attributes:
      name:
          The full name of the asset. For example: “//compute.googleapis
          .com/projects/my_project_123/zones/zone1/instances/instance1”
          See `Resource names <https://cloud.google.com/apis/design/reso
          urce_names#full_resource_name>`__ for more information.
      asset_type:
          The type of the asset. For example:
          “compute.googleapis.com/Disk”  See `Supported asset types
          <https://cloud.google.com/asset-inventory/docs/supported-
          asset-types>`__ for more information.
      resource:
          A representation of the resource.
      iam_policy:
          A representation of the Cloud IAM policy set on a Google Cloud
          resource. There can be a maximum of one Cloud IAM policy set
          on any given resource. In addition, Cloud IAM policies inherit
          their granted access scope from any policies set on parent
          resources in the resource hierarchy. Therefore, the
          effectively policy is the union of both the policy set on this
          resource and each policy set on all of the resource’s ancestry
          resource levels in the hierarchy. See `this topic
          <https://cloud.google.com/iam/docs/policies#inheritance>`__
          for more information.
      org_policy:
          A representation of an `organization policy
          <https://cloud.google.com/resource-manager/docs/organization-
          policy/overview#organization_policy>`__. There can be more
          than one organization policy with different constraints set on
          a given resource.
      access_context_policy:
          A representation of an `access policy
          <https://cloud.google.com/access-context-
          manager/docs/overview#access-policies>`__.
      ancestors:
          The ancestry path of an asset in Google Cloud `resource
          hierarchy <https://cloud.google.com/resource-
          manager/docs/cloud-platform-resource-hierarchy>`__,
          represented as a list of relative resource names. An ancestry
          path starts with the closest ancestor in the hierarchy and
          ends at root. If the asset is a project, folder, or
          organization, the ancestry path starts from the asset itself.
          For example: ``["projects/123456789", "folders/5432",
          "organizations/1234"]``
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1.Asset)
    },
)
_sym_db.RegisterMessage(Asset)

Resource = _reflection.GeneratedProtocolMessageType(
    "Resource",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESOURCE,
        "__module__": "google.cloud.asset_v1.proto.assets_pb2",
        "__doc__": """A representation of a Google Cloud resource.
  
  
  Attributes:
      version:
          The API version. For example: “v1”
      discovery_document_uri:
          The URL of the discovery document containing the resource’s
          JSON schema. For example:
          “https://www.googleapis.com/discovery/v1/apis/compute/v1/rest”
          This value is unspecified for resources that do not have an
          API based on a discovery document, such as Cloud Bigtable.
      discovery_name:
          The JSON schema name listed in the discovery document. For
          example: “Project”  This value is unspecified for resources
          that do not have an API based on a discovery document, such as
          Cloud Bigtable.
      resource_url:
          The REST URL for accessing the resource. An HTTP ``GET``
          request using this URL returns the resource itself. For
          example:
          “https://cloudresourcemanager.googleapis.com/v1/projects/my-
          project-123”  This value is unspecified for resources without
          a REST API.
      parent:
          The full name of the immediate parent of this resource. See
          `Resource Names <https://cloud.google.com/apis/design/resource
          _names#full_resource_name>`__ for more information.  For
          Google Cloud assets, this value is the parent resource defined
          in the `Cloud IAM policy hierarchy <https://cloud.google.com/i
          am/docs/overview#policy_hierarchy>`__. For example: “//cloudre
          sourcemanager.googleapis.com/projects/my_project_123”  For
          third-party assets, this field may be set differently.
      data:
          The content of the resource, in which some sensitive fields
          are removed and may not be present.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1.Resource)
    },
)
_sym_db.RegisterMessage(Resource)


DESCRIPTOR._options = None
_ASSET._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/asset_v1p2beta1/proto/asset_service.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.asset_v1p2beta1.proto import (
    assets_pb2 as google_dot_cloud_dot_asset__v1p2beta1_dot_proto_dot_assets__pb2,
)
from google.longrunning import (
    operations_pb2 as google_dot_longrunning_dot_operations__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/asset_v1p2beta1/proto/asset_service.proto",
    package="google.cloud.asset.v1p2beta1",
    syntax="proto3",
    serialized_options=b"\n com.google.cloud.asset.v1p2beta1B\021AssetServiceProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/asset/v1p2beta1;asset\252\002\034Google.Cloud.Asset.V1p2Beta1\312\002\034Google\\Cloud\\Asset\\V1p2Beta1",
    serialized_pb=b'\n6google/cloud/asset_v1p2beta1/proto/asset_service.proto\x12\x1cgoogle.cloud.asset.v1p2beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a/google/cloud/asset_v1p2beta1/proto/assets.proto\x1a#google/longrunning/operations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto"u\n\x11\x43reateFeedRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x14\n\x07\x66\x65\x65\x64_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x35\n\x04\x66\x65\x65\x64\x18\x03 \x01(\x0b\x32".google.cloud.asset.v1p2beta1.FeedB\x03\xe0\x41\x02"F\n\x0eGetFeedRequest\x12\x34\n\x04name\x18\x01 \x01(\tB&\xe0\x41\x02\xfa\x41 \n\x1e\x63loudasset.googleapis.com/Feed"\'\n\x10ListFeedsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02"F\n\x11ListFeedsResponse\x12\x31\n\x05\x66\x65\x65\x64s\x18\x01 \x03(\x0b\x32".google.cloud.asset.v1p2beta1.Feed"\x80\x01\n\x11UpdateFeedRequest\x12\x35\n\x04\x66\x65\x65\x64\x18\x01 \x01(\x0b\x32".google.cloud.asset.v1p2beta1.FeedB\x03\xe0\x41\x02\x12\x34\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02"I\n\x11\x44\x65leteFeedRequest\x12\x34\n\x04name\x18\x01 \x01(\tB&\xe0\x41\x02\xfa\x41 \n\x1e\x63loudasset.googleapis.com/Feed"f\n\x0cOutputConfig\x12G\n\x0fgcs_destination\x18\x01 \x01(\x0b\x32,.google.cloud.asset.v1p2beta1.GcsDestinationH\x00\x42\r\n\x0b\x64\x65stination"-\n\x0eGcsDestination\x12\r\n\x03uri\x18\x01 \x01(\tH\x00\x42\x0c\n\nobject_uri""\n\x11PubsubDestination\x12\r\n\x05topic\x18\x01 \x01(\t"p\n\x10\x46\x65\x65\x64OutputConfig\x12M\n\x12pubsub_destination\x18\x01 \x01(\x0b\x32/.google.cloud.asset.v1p2beta1.PubsubDestinationH\x00\x42\r\n\x0b\x64\x65stination"\xe9\x02\n\x04\x46\x65\x65\x64\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x13\n\x0b\x61sset_names\x18\x02 \x03(\t\x12\x13\n\x0b\x61sset_types\x18\x03 \x03(\t\x12?\n\x0c\x63ontent_type\x18\x04 \x01(\x0e\x32).google.cloud.asset.v1p2beta1.ContentType\x12O\n\x12\x66\x65\x65\x64_output_config\x18\x05 \x01(\x0b\x32..google.cloud.asset.v1p2beta1.FeedOutputConfigB\x03\xe0\x41\x02:\x91\x01\xea\x41\x8d\x01\n\x1e\x63loudasset.googleapis.com/Feed\x12\x1fprojects/{project}/feeds/{feed}\x12\x1d\x66olders/{folder}/feeds/{feed}\x12)organizations/{organization}/feeds/{feed} \x01*I\n\x0b\x43ontentType\x12\x1c\n\x18\x43ONTENT_TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08RESOURCE\x10\x01\x12\x0e\n\nIAM_POLICY\x10\x02\x32\xbf\x06\n\x0c\x41ssetService\x12\x94\x01\n\nCreateFeed\x12/.google.cloud.asset.v1p2beta1.CreateFeedRequest\x1a".google.cloud.asset.v1p2beta1.Feed"1\x82\xd3\xe4\x93\x02""\x1d/v1p2beta1/{parent=*/*}/feeds:\x01*\xda\x41\x06parent\x12\x89\x01\n\x07GetFeed\x12,.google.cloud.asset.v1p2beta1.GetFeedRequest\x1a".google.cloud.asset.v1p2beta1.Feed",\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1p2beta1/{name=*/*/feeds/*}\xda\x41\x04name\x12\x9c\x01\n\tListFeeds\x12..google.cloud.asset.v1p2beta1.ListFeedsRequest\x1a/.google.cloud.asset.v1p2beta1.ListFeedsResponse".\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1p2beta1/{parent=*/*}/feeds\xda\x41\x06parent\x12\x97\x01\n\nUpdateFeed\x12/.google.cloud.asset.v1p2beta1.UpdateFeedRequest\x1a".google.cloud.asset.v1p2beta1.Feed"4\x82\xd3\xe4\x93\x02\'2"/v1p2beta1/{feed.name=*/*/feeds/*}:\x01*\xda\x41\x04\x66\x65\x65\x64\x12\x83\x01\n\nDeleteFeed\x12/.google.cloud.asset.v1p2beta1.DeleteFeedRequest\x1a\x16.google.protobuf.Empty",\x82\xd3\xe4\x93\x02\x1f*\x1d/v1p2beta1/{name=*/*/feeds/*}\xda\x41\x04name\x1aM\xca\x41\x19\x63loudasset.googleapis.com\xd2\x41.https://www.googleapis.com/auth/cloud-platformB\xb8\x01\n com.google.cloud.asset.v1p2beta1B\x11\x41ssetServiceProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/asset/v1p2beta1;asset\xaa\x02\x1cGoogle.Cloud.Asset.V1p2Beta1\xca\x02\x1cGoogle\\Cloud\\Asset\\V1p2Beta1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_asset__v1p2beta1_dot_proto_dot_assets__pb2.DESCRIPTOR,
        google_dot_longrunning_dot_operations__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
    ],
)

_CONTENTTYPE = _descriptor.EnumDescriptor(
    name="ContentType",
    full_name="google.cloud.asset.v1p2beta1.ContentType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="CONTENT_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="RESOURCE", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="IAM_POLICY", index=2, number=2, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1560,
    serialized_end=1633,
)
_sym_db.RegisterEnumDescriptor(_CONTENTTYPE)

ContentType = enum_type_wrapper.EnumTypeWrapper(_CONTENTTYPE)
CONTENT_TYPE_UNSPECIFIED = 0
RESOURCE = 1
IAM_POLICY = 2


_CREATEFEEDREQUEST = _descriptor.Descriptor(
    name="CreateFeedRequest",
    full_name="google.cloud.asset.v1p2beta1.CreateFeedRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.asset.v1p2beta1.CreateFeedRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="feed_id",
            full_name="google.cloud.asset.v1p2beta1.CreateFeedRequest.feed_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="feed",
            full_name="google.cloud.asset.v1p2beta1.CreateFeedRequest.feed",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=385,
    serialized_end=502,
)


_GETFEEDREQUEST = _descriptor.Descriptor(
    name="GetFeedRequest",
    full_name="google.cloud.asset.v1p2beta1.GetFeedRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.asset.v1p2beta1.GetFeedRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A \n\036cloudasset.googleapis.com/Feed",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=504,
    serialized_end=574,
)


_LISTFEEDSREQUEST = _descriptor.Descriptor(
    name="ListFeedsRequest",
    full_name="google.cloud.asset.v1p2beta1.ListFeedsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.asset.v1p2beta1.ListFeedsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=576,
    serialized_end=615,
)


_LISTFEEDSRESPONSE = _descriptor.Descriptor(
    name="ListFeedsResponse",
    full_name="google.cloud.asset.v1p2beta1.ListFeedsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="feeds",
            full_name="google.cloud.asset.v1p2beta1.ListFeedsResponse.feeds",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=617,
    serialized_end=687,
)


_UPDATEFEEDREQUEST = _descriptor.Descriptor(
    name="UpdateFeedRequest",
    full_name="google.cloud.asset.v1p2beta1.UpdateFeedRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="feed",
            full_name="google.cloud.asset.v1p2beta1.UpdateFeedRequest.feed",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.asset.v1p2beta1.UpdateFeedRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=690,
    serialized_end=818,
)


_DELETEFEEDREQUEST = _descriptor.Descriptor(
    name="DeleteFeedRequest",
    full_name="google.cloud.asset.v1p2beta1.DeleteFeedRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.asset.v1p2beta1.DeleteFeedRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A \n\036cloudasset.googleapis.com/Feed",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=820,
    serialized_end=893,
)


_OUTPUTCONFIG = _descriptor.Descriptor(
    name="OutputConfig",
    full_name="google.cloud.asset.v1p2beta1.OutputConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="gcs_destination",
            full_name="google.cloud.asset.v1p2beta1.OutputConfig.gcs_destination",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="destination",
            full_name="google.cloud.asset.v1p2beta1.OutputConfig.destination",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=895,
    serialized_end=997,
)


_GCSDESTINATION = _descriptor.Descriptor(
    name="GcsDestination",
    full_name="google.cloud.asset.v1p2beta1.GcsDestination",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="uri",
            full_name="google.cloud.asset.v1p2beta1.GcsDestination.uri",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="object_uri",
            full_name="google.cloud.asset.v1p2beta1.GcsDestination.object_uri",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=999,
    serialized_end=1044,
)


_PUBSUBDESTINATION = _descriptor.Descriptor(
    name="PubsubDestination",
    full_name="google.cloud.asset.v1p2beta1.PubsubDestination",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="topic",
            full_name="google.cloud.asset.v1p2beta1.PubsubDestination.topic",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1046,
    serialized_end=1080,
)


_FEEDOUTPUTCONFIG = _descriptor.Descriptor(
    name="FeedOutputConfig",
    full_name="google.cloud.asset.v1p2beta1.FeedOutputConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="pubsub_destination",
            full_name="google.cloud.asset.v1p2beta1.FeedOutputConfig.pubsub_destination",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="destination",
            full_name="google.cloud.asset.v1p2beta1.FeedOutputConfig.destination",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=1082,
    serialized_end=1194,
)


_FEED = _descriptor.Descriptor(
    name="Feed",
    full_name="google.cloud.asset.v1p2beta1.Feed",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.asset.v1p2beta1.Feed.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="asset_names",
            full_name="google.cloud.asset.v1p2beta1.Feed.asset_names",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="asset_types",
            full_name="google.cloud.asset.v1p2beta1.Feed.asset_types",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="content_type",
            full_name="google.cloud.asset.v1p2beta1.Feed.content_type",
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="feed_output_config",
            full_name="google.cloud.asset.v1p2beta1.Feed.feed_output_config",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"\352A\215\001\n\036cloudasset.googleapis.com/Feed\022\037projects/{project}/feeds/{feed}\022\035folders/{folder}/feeds/{feed}\022)organizations/{organization}/feeds/{feed} \001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1197,
    serialized_end=1558,
)

_CREATEFEEDREQUEST.fields_by_name["feed"].message_type = _FEED
_LISTFEEDSRESPONSE.fields_by_name["feeds"].message_type = _FEED
_UPDATEFEEDREQUEST.fields_by_name["feed"].message_type = _FEED
_UPDATEFEEDREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_OUTPUTCONFIG.fields_by_name["gcs_destination"].message_type = _GCSDESTINATION
_OUTPUTCONFIG.oneofs_by_name["destination"].fields.append(
    _OUTPUTCONFIG.fields_by_name["gcs_destination"]
)
_OUTPUTCONFIG.fields_by_name[
    "gcs_destination"
].containing_oneof = _OUTPUTCONFIG.oneofs_by_name["destination"]
_GCSDESTINATION.oneofs_by_name["object_uri"].fields.append(
    _GCSDESTINATION.fields_by_name["uri"]
)
_GCSDESTINATION.fields_by_name["uri"].containing_oneof = _GCSDESTINATION.oneofs_by_name[
    "object_uri"
]
_FEEDOUTPUTCONFIG.fields_by_name["pubsub_destination"].message_type = _PUBSUBDESTINATION
_FEEDOUTPUTCONFIG.oneofs_by_name["destination"].fields.append(
    _FEEDOUTPUTCONFIG.fields_by_name["pubsub_destination"]
)
_FEEDOUTPUTCONFIG.fields_by_name[
    "pubsub_destination"
].containing_oneof = _FEEDOUTPUTCONFIG.oneofs_by_name["destination"]
_FEED.fields_by_name["content_type"].enum_type = _CONTENTTYPE
_FEED.fields_by_name["feed_output_config"].message_type = _FEEDOUTPUTCONFIG
DESCRIPTOR.message_types_by_name["CreateFeedRequest"] = _CREATEFEEDREQUEST
DESCRIPTOR.message_types_by_name["GetFeedRequest"] = _GETFEEDREQUEST
DESCRIPTOR.message_types_by_name["ListFeedsRequest"] = _LISTFEEDSREQUEST
DESCRIPTOR.message_types_by_name["ListFeedsResponse"] = _LISTFEEDSRESPONSE
DESCRIPTOR.message_types_by_name["UpdateFeedRequest"] = _UPDATEFEEDREQUEST
DESCRIPTOR.message_types_by_name["DeleteFeedRequest"] = _DELETEFEEDREQUEST
DESCRIPTOR.message_types_by_name["OutputConfig"] = _OUTPUTCONFIG
DESCRIPTOR.message_types_by_name["GcsDestination"] = _GCSDESTINATION
DESCRIPTOR.message_types_by_name["PubsubDestination"] = _PUBSUBDESTINATION
DESCRIPTOR.message_types_by_name["FeedOutputConfig"] = _FEEDOUTPUTCONFIG
DESCRIPTOR.message_types_by_name["Feed"] = _FEED
DESCRIPTOR.enum_types_by_name["ContentType"] = _CONTENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateFeedRequest = _reflection.GeneratedProtocolMessageType(
    "CreateFeedRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATEFEEDREQUEST,
        "__module__": "google.cloud.asset_v1p2beta1.proto.asset_service_pb2",
        "__doc__": """Create asset feed request.
  
  
  Attributes:
      parent:
          Required. The name of the project/folder/organization where
          this feed should be created in. It can only be an organization
          number (such as “organizations/123”), a folder number (such as
          “folders/123”), a project ID (such as “projects/my-project-
          id”)“, or a project number (such as”projects/12345").
      feed_id:
          Required. This is the client-assigned asset feed identifier
          and it needs to be unique under a specific parent
          project/folder/organization.
      feed:
          Required. The feed details. The field ``name`` must be empty
          and it will be generated in the format of:
          projects/project_number/feeds/feed_id
          folders/folder_number/feeds/feed_id
          organizations/organization_number/feeds/feed_id
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.CreateFeedRequest)
    },
)
_sym_db.RegisterMessage(CreateFeedRequest)

GetFeedRequest = _reflection.GeneratedProtocolMessageType(
    "GetFeedRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETFEEDREQUEST,
        "__module__": "google.cloud.asset_v1p2beta1.proto.asset_service_pb2",
        "__doc__": """Get asset feed request.
  
  
  Attributes:
      name:
          Required. The name of the Feed and it must be in the format
          of: projects/project_number/feeds/feed_id
          folders/folder_number/feeds/feed_id
          organizations/organization_number/feeds/feed_id
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.GetFeedRequest)
    },
)
_sym_db.RegisterMessage(GetFeedRequest)

ListFeedsRequest = _reflection.GeneratedProtocolMessageType(
    "ListFeedsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTFEEDSREQUEST,
        "__module__": "google.cloud.asset_v1p2beta1.proto.asset_service_pb2",
        "__doc__": """List asset feeds request.
  
  
  Attributes:
      parent:
          Required. The parent project/folder/organization whose feeds
          are to be listed. It can only be using
          project/folder/organization number (such as “folders/12345”)“,
          or a project ID (such as”projects/my-project-id").
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.ListFeedsRequest)
    },
)
_sym_db.RegisterMessage(ListFeedsRequest)

ListFeedsResponse = _reflection.GeneratedProtocolMessageType(
    "ListFeedsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTFEEDSRESPONSE,
        "__module__": "google.cloud.asset_v1p2beta1.proto.asset_service_pb2",
        "__doc__": """
    Attributes:
      feeds:
          A list of feeds.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.ListFeedsResponse)
    },
)
_sym_db.RegisterMessage(ListFeedsResponse)

UpdateFeedRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateFeedRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATEFEEDREQUEST,
        "__module__": "google.cloud.asset_v1p2beta1.proto.asset_service_pb2",
        "__doc__": """Update asset feed request.
  
  
  Attributes:
      feed:
          Required. The new values of feed details. It must match an
          existing feed and the field ``name`` must be in the format of:
          projects/project_number/feeds/feed_id or
          folders/folder_number/feeds/feed_id or
          organizations/organization_number/feeds/feed_id.
      update_mask:
          Required. Only updates the ``feed`` fields indicated by this
          mask. The field mask must not be empty, and it must not
          contain fields that are immutable or only set by the server.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.UpdateFeedRequest)
    },
)
_sym_db.RegisterMessage(UpdateFeedRequest)

DeleteFeedRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteFeedRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETEFEEDREQUEST,
        "__module__": "google.cloud.asset_v1p2beta1.proto.asset_service_pb2",
        "__doc__": """
    Attributes:
      name:
          Required. The name of the feed and it must be in the format
          of: projects/project_number/feeds/feed_id
          folders/folder_number/feeds/feed_id
          organizations/organization_number/feeds/feed_id
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.DeleteFeedRequest)
    },
)
_sym_db.RegisterMessage(DeleteFeedRequest)

OutputConfig = _reflection.GeneratedProtocolMessageType(
    "OutputConfig",
    (_message.Message,),
    {
        "DESCRIPTOR": _OUTPUTCONFIG,
        "__module__": "google.cloud.asset_v1p2beta1.proto.asset_service_pb2",
        "__doc__": """Output configuration for export assets destination.
  
  
  Attributes:
      destination:
          Asset export destination.
      gcs_destination:
          Destination on Cloud Storage.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.OutputConfig)
    },
)
_sym_db.RegisterMessage(OutputConfig)

GcsDestination = _reflection.GeneratedProtocolMessageType(
    "GcsDestination",
    (_message.Message,),
    {
        "DESCRIPTOR": _GCSDESTINATION,
        "__module__": "google.cloud.asset_v1p2beta1.proto.asset_service_pb2",
        "__doc__": """A Cloud Storage location.
  
  
  Attributes:
      object_uri:
          Required.
      uri:
          The uri of the Cloud Storage object. It’s the same uri that is
          used by gsutil. For example: “gs://bucket_name/object_name”.
          See `Viewing and Editing Object Metadata
          <https://cloud.google.com/storage/docs/viewing-editing-
          metadata>`__ for more information.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.GcsDestination)
    },
)
_sym_db.RegisterMessage(GcsDestination)

PubsubDestination = _reflection.GeneratedProtocolMessageType(
    "PubsubDestination",
    (_message.Message,),
    {
        "DESCRIPTOR": _PUBSUBDESTINATION,
        "__module__": "google.cloud.asset_v1p2beta1.proto.asset_service_pb2",
        "__doc__": """A Cloud Pubsub destination.
  
  
  Attributes:
      topic:
          The name of the Cloud Pub/Sub topic to publish to. For
          example: ``projects/PROJECT_ID/topics/TOPIC_ID``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.PubsubDestination)
    },
)
_sym_db.RegisterMessage(PubsubDestination)

FeedOutputConfig = _reflection.GeneratedProtocolMessageType(
    "FeedOutputConfig",
    (_message.Message,),
    {
        "DESCRIPTOR": _FEEDOUTPUTCONFIG,
        "__module__": "google.cloud.asset_v1p2beta1.proto.asset_service_pb2",
        "__doc__": """Output configuration for asset feed destination.
  
  
  Attributes:
      destination:
          Asset feed destination.
      pubsub_destination:
          Destination on Cloud Pubsub.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.FeedOutputConfig)
    },
)
_sym_db.RegisterMessage(FeedOutputConfig)

Feed = _reflection.GeneratedProtocolMessageType(
    "Feed",
    (_message.Message,),
    {
        "DESCRIPTOR": _FEED,
        "__module__": "google.cloud.asset_v1p2beta1.proto.asset_service_pb2",
        "__doc__": """An asset feed used to export asset updates to a
  destinations. An asset feed filter controls what updates are exported.
  The asset feed must be created within a project, organization, or
  folder. Supported destinations are: Cloud Pub/Sub topics.
  
  
  Attributes:
      name:
          Required. The format will be
          projects/{project_number}/feeds/{client-
          assigned_feed_identifier} or
          folders/{folder_number}/feeds/{client-
          assigned_feed_identifier} or
          organizations/{organization_number}/feeds/{client-
          assigned_feed_identifier}  The client-assigned feed identifier
          must be unique within the parent project/folder/organization.
      asset_names:
          A list of the full names of the assets to receive updates. You
          must specify either or both of asset_names and asset_types.
          Only asset updates matching specified asset_names and
          asset_types are exported to the feed. For example: ``//compute
          .googleapis.com/projects/my_project_123/zones/zone1/instances/
          instance1``. See `Resource Names <https://cloud.google.com/api
          s/design/resource_names#full_resource_name>`__ for more info.
      asset_types:
          A list of types of the assets to receive updates. You must
          specify either or both of asset_names and asset_types. Only
          asset updates matching specified asset_names and asset_types
          are exported to the feed. For example:
          “compute.googleapis.com/Disk” See `Introduction to Cloud Asset
          Inventory <https://cloud.google.com/resource-
          manager/docs/cloud-asset-inventory/overview>`__ for all
          supported asset types.
      content_type:
          Asset content type. If not specified, no content but the asset
          name and type will be returned.
      feed_output_config:
          Required. Feed output configuration defining where the asset
          updates are published to.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.Feed)
    },
)
_sym_db.RegisterMessage(Feed)


DESCRIPTOR._options = None
_CREATEFEEDREQUEST.fields_by_name["parent"]._options = None
_CREATEFEEDREQUEST.fields_by_name["feed_id"]._options = None
_CREATEFEEDREQUEST.fields_by_name["feed"]._options = None
_GETFEEDREQUEST.fields_by_name["name"]._options = None
_LISTFEEDSREQUEST.fields_by_name["parent"]._options = None
_UPDATEFEEDREQUEST.fields_by_name["feed"]._options = None
_UPDATEFEEDREQUEST.fields_by_name["update_mask"]._options = None
_DELETEFEEDREQUEST.fields_by_name["name"]._options = None
_FEED.fields_by_name["name"]._options = None
_FEED.fields_by_name["feed_output_config"]._options = None
_FEED._options = None

_ASSETSERVICE = _descriptor.ServiceDescriptor(
    name="AssetService",
    full_name="google.cloud.asset.v1p2beta1.AssetService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\312A\031cloudasset.googleapis.com\322A.https://www.googleapis.com/auth/cloud-platform",
    serialized_start=1636,
    serialized_end=2467,
    methods=[
        _descriptor.MethodDescriptor(
            name="CreateFeed",
            full_name="google.cloud.asset.v1p2beta1.AssetService.CreateFeed",
            index=0,
            containing_service=None,
            input_type=_CREATEFEEDREQUEST,
            output_type=_FEED,
            serialized_options=b'\202\323\344\223\002""\035/v1p2beta1/{parent=*/*}/feeds:\001*\332A\006parent',
        ),
        _descriptor.MethodDescriptor(
            name="GetFeed",
            full_name="google.cloud.asset.v1p2beta1.AssetService.GetFeed",
            index=1,
            containing_service=None,
            input_type=_GETFEEDREQUEST,
            output_type=_FEED,
            serialized_options=b"\202\323\344\223\002\037\022\035/v1p2beta1/{name=*/*/feeds/*}\332A\004name",
        ),
        _descriptor.MethodDescriptor(
            name="ListFeeds",
            full_name="google.cloud.asset.v1p2beta1.AssetService.ListFeeds",
            index=2,
            containing_service=None,
            input_type=_LISTFEEDSREQUEST,
            output_type=_LISTFEEDSRESPONSE,
            serialized_options=b"\202\323\344\223\002\037\022\035/v1p2beta1/{parent=*/*}/feeds\332A\006parent",
        ),
        _descriptor.MethodDescriptor(
            name="UpdateFeed",
            full_name="google.cloud.asset.v1p2beta1.AssetService.UpdateFeed",
            index=3,
            containing_service=None,
            input_type=_UPDATEFEEDREQUEST,
            output_type=_FEED,
            serialized_options=b"\202\323\344\223\002'2\"/v1p2beta1/{feed.name=*/*/feeds/*}:\001*\332A\004feed",
        ),
        _descriptor.MethodDescriptor(
            name="DeleteFeed",
            full_name="google.cloud.asset.v1p2beta1.AssetService.DeleteFeed",
            index=4,
            containing_service=None,
            input_type=_DELETEFEEDREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002\037*\035/v1p2beta1/{name=*/*/feeds/*}\332A\004name",
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_ASSETSERVICE)

DESCRIPTOR.services_by_name["AssetService"] = _ASSETSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Wrappers for protocol buffer enum types."""

import enum


class ContentType(enum.IntEnum):
    """
    Asset content type.

    Attributes:
      CONTENT_TYPE_UNSPECIFIED (int): Unspecified content type.
      RESOURCE (int): Resource metadata.
      IAM_POLICY (int): The actual IAM policy set on a resource.
      ORG_POLICY (int): The Cloud Organization Policy set on an asset.
      ACCESS_POLICY (int): The Cloud Access context mananger Policy set on an asset.
    """

    CONTENT_TYPE_UNSPECIFIED = 0
    RESOURCE = 1
    IAM_POLICY = 2
    ORG_POLICY = 4
    ACCESS_POLICY = 5


class DeviceEncryptionStatus(enum.IntEnum):
    """
    The encryption state of the device.

    Attributes:
      ENCRYPTION_UNSPECIFIED (int): The encryption status of the device is not specified or not known.
      ENCRYPTION_UNSUPPORTED (int): The device does not support encryption.
      UNENCRYPTED (int): The device supports encryption, but is currently unencrypted.
      ENCRYPTED (int): The device is encrypted.
    """

    ENCRYPTION_UNSPECIFIED = 0
    ENCRYPTION_UNSUPPORTED = 1
    UNENCRYPTED = 2
    ENCRYPTED = 3


class DeviceManagementLevel(enum.IntEnum):
    """
    The degree to which the device is managed by the Cloud organization.

    Attributes:
      MANAGEMENT_UNSPECIFIED (int): The device's management level is not specified or not known.
      NONE (int): The device is not managed.
      BASIC (int): Basic management is enabled, which is generally limited to monitoring and
      wiping the corporate account.
      COMPLETE (int): Complete device management. This includes more thorough monitoring and the
      ability to directly manage the device (such as remote wiping). This can be
      enabled through the Android Enterprise Platform.
    """

    MANAGEMENT_UNSPECIFIED = 0
    NONE = 1
    BASIC = 2
    COMPLETE = 3


class NullValue(enum.IntEnum):
    """
    ``NullValue`` is a singleton enumeration to represent the null value
    for the ``Value`` type union.

    The JSON representation for ``NullValue`` is JSON ``null``.

    Attributes:
      NULL_VALUE (int): Null value.
    """

    NULL_VALUE = 0


class OsType(enum.IntEnum):
    """
    The operating system type of the device.
    Next id: 7

    Attributes:
      OS_UNSPECIFIED (int): The operating system of the device is not specified or not known.
      DESKTOP_MAC (int): A desktop Mac operating system.
      DESKTOP_WINDOWS (int): A desktop Windows operating system.
      DESKTOP_LINUX (int): A desktop Linux operating system.
      DESKTOP_CHROME_OS (int): A desktop ChromeOS operating system.
      ANDROID (int): An Android operating system.
      IOS (int): An iOS operating system.
    """

    OS_UNSPECIFIED = 0
    DESKTOP_MAC = 1
    DESKTOP_WINDOWS = 2
    DESKTOP_LINUX = 3
    DESKTOP_CHROME_OS = 6
    ANDROID = 4
    IOS = 5


class BasicLevel(object):
    class ConditionCombiningFunction(enum.IntEnum):
        """
        Options for how the ``conditions`` list should be combined to
        determine if this ``AccessLevel`` is applied. Default is AND.

        Attributes:
          AND (int): All ``Conditions`` must be true for the ``BasicLevel`` to be true.
          OR (int): If at least one ``Condition`` is true, then the ``BasicLevel`` is
          true.
        """

        AND = 0
        OR = 1


class Policy(object):
    class ListPolicy(object):
        class AllValues(enum.IntEnum):
            """
            This enum can be used to set ``Policies`` that apply to all possible
            configuration values rather than specific values in ``allowed_values``
            or ``denied_values``.

            Settting this to ``ALLOW`` will mean this ``Policy`` allows all values.
            Similarly, setting it to ``DENY`` will mean no values are allowed. If
            set to either ``ALLOW`` or
            ``DENY,``\ allowed_values\ ``and``\ denied_values\ ``must be unset. Setting this to``\ ALL_VALUES_UNSPECIFIED\ ``allows for setting``\ allowed_values\ ``and``\ denied_values`.

            Attributes:
              ALL_VALUES_UNSPECIFIED (int): Indicates that allowed_values or denied_values must be set.
              ALLOW (int): A policy with this set allows all values.
              DENY (int): A policy with this set denies all values.
            """

            ALL_VALUES_UNSPECIFIED = 0
            ALLOW = 1
            DENY = 2


class ServicePerimeter(object):
    class PerimeterType(enum.IntEnum):
        """
        Specifies the type of the Perimeter. There are two types: regular and
        bridge. Regular Service Perimeter contains resources, access levels, and
        restricted services. Every resource can be in at most ONE
        regular Service Perimeter.

        In addition to being in a regular service perimeter, a resource can also
        be in zero or more perimeter bridges.  A perimeter bridge only contains
        resources.  Cross project operations are permitted if all effected
        resources share some perimeter (whether bridge or regular). Perimeter
        Bridge does not contain access levels or services: those are governed
        entirely by the regular perimeter that resource is in.

        Perimeter Bridges are typically useful when building more complex toplogies
        with many independent perimeters that need to share some data with a common
        perimeter, but should not be able to share data among themselves.

        Attributes:
          PERIMETER_TYPE_REGULAR (int): Regular Perimeter.
          PERIMETER_TYPE_BRIDGE (int): Perimeter Bridge.
        """

        PERIMETER_TYPE_REGULAR = 0
        PERIMETER_TYPE_BRIDGE = 1



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/asset_v1p2beta1/proto/assets.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.iam.v1 import iam_policy_pb2 as google_dot_iam_dot_v1_dot_policy__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/asset_v1p2beta1/proto/assets.proto",
    package="google.cloud.asset.v1p2beta1",
    syntax="proto3",
    serialized_options=b"\n com.google.cloud.asset.v1p2beta1B\nAssetProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/asset/v1p2beta1;asset\370\001\001\252\002\034Google.Cloud.Asset.v1p2beta1\312\002\034Google\\Cloud\\Asset\\v1p2beta1",
    serialized_pb=b'\n/google/cloud/asset_v1p2beta1/proto/assets.proto\x12\x1cgoogle.cloud.asset.v1p2beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x1agoogle/iam/v1/policy.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\x8e\x01\n\rTemporalAsset\x12\x38\n\x06window\x18\x01 \x01(\x0b\x32(.google.cloud.asset.v1p2beta1.TimeWindow\x12\x0f\n\x07\x64\x65leted\x18\x02 \x01(\x08\x12\x32\n\x05\x61sset\x18\x03 \x01(\x0b\x32#.google.cloud.asset.v1p2beta1.Asset"j\n\nTimeWindow\x12.\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp"\xa1\x01\n\x05\x41sset\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nasset_type\x18\x02 \x01(\t\x12\x38\n\x08resource\x18\x03 \x01(\x0b\x32&.google.cloud.asset.v1p2beta1.Resource\x12)\n\niam_policy\x18\x04 \x01(\x0b\x32\x15.google.iam.v1.Policy\x12\x11\n\tancestors\x18\x06 \x03(\t"\xa0\x01\n\x08Resource\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x1e\n\x16\x64iscovery_document_uri\x18\x02 \x01(\t\x12\x16\n\x0e\x64iscovery_name\x18\x03 \x01(\t\x12\x14\n\x0cresource_url\x18\x04 \x01(\t\x12\x0e\n\x06parent\x18\x05 \x01(\t\x12%\n\x04\x64\x61ta\x18\x06 \x01(\x0b\x32\x17.google.protobuf.StructB\xb4\x01\n com.google.cloud.asset.v1p2beta1B\nAssetProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/asset/v1p2beta1;asset\xf8\x01\x01\xaa\x02\x1cGoogle.Cloud.Asset.v1p2beta1\xca\x02\x1cGoogle\\Cloud\\Asset\\v1p2beta1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_iam_dot_v1_dot_policy__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_any__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
    ],
)


_TEMPORALASSET = _descriptor.Descriptor(
    name="TemporalAsset",
    full_name="google.cloud.asset.v1p2beta1.TemporalAsset",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="window",
            full_name="google.cloud.asset.v1p2beta1.TemporalAsset.window",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="deleted",
            full_name="google.cloud.asset.v1p2beta1.TemporalAsset.deleted",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="asset",
            full_name="google.cloud.asset.v1p2beta1.TemporalAsset.asset",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=230,
    serialized_end=372,
)


_TIMEWINDOW = _descriptor.Descriptor(
    name="TimeWindow",
    full_name="google.cloud.asset.v1p2beta1.TimeWindow",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="start_time",
            full_name="google.cloud.asset.v1p2beta1.TimeWindow.start_time",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="end_time",
            full_name="google.cloud.asset.v1p2beta1.TimeWindow.end_time",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=374,
    serialized_end=480,
)


_ASSET = _descriptor.Descriptor(
    name="Asset",
    full_name="google.cloud.asset.v1p2beta1.Asset",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.asset.v1p2beta1.Asset.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="asset_type",
            full_name="google.cloud.asset.v1p2beta1.Asset.asset_type",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="resource",
            full_name="google.cloud.asset.v1p2beta1.Asset.resource",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="iam_policy",
            full_name="google.cloud.asset.v1p2beta1.Asset.iam_policy",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="ancestors",
            full_name="google.cloud.asset.v1p2beta1.Asset.ancestors",
            index=4,
            number=6,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=483,
    serialized_end=644,
)


_RESOURCE = _descriptor.Descriptor(
    name="Resource",
    full_name="google.cloud.asset.v1p2beta1.Resource",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="version",
            full_name="google.cloud.asset.v1p2beta1.Resource.version",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="discovery_document_uri",
            full_name="google.cloud.asset.v1p2beta1.Resource.discovery_document_uri",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="discovery_name",
            full_name="google.cloud.asset.v1p2beta1.Resource.discovery_name",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="resource_url",
            full_name="google.cloud.asset.v1p2beta1.Resource.resource_url",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.asset.v1p2beta1.Resource.parent",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="data",
            full_name="google.cloud.asset.v1p2beta1.Resource.data",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=647,
    serialized_end=807,
)

_TEMPORALASSET.fields_by_name["window"].message_type = _TIMEWINDOW
_TEMPORALASSET.fields_by_name["asset"].message_type = _ASSET
_TIMEWINDOW.fields_by_name[
    "start_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TIMEWINDOW.fields_by_name[
    "end_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ASSET.fields_by_name["resource"].message_type = _RESOURCE
_ASSET.fields_by_name[
    "iam_policy"
].message_type = (
    google_dot_iam_dot_v1_dot_policy__pb2.google_dot_iam_dot_v1_dot_policy__pb2._POLICY
)
_RESOURCE.fields_by_name[
    "data"
].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
DESCRIPTOR.message_types_by_name["TemporalAsset"] = _TEMPORALASSET
DESCRIPTOR.message_types_by_name["TimeWindow"] = _TIMEWINDOW
DESCRIPTOR.message_types_by_name["Asset"] = _ASSET
DESCRIPTOR.message_types_by_name["Resource"] = _RESOURCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TemporalAsset = _reflection.GeneratedProtocolMessageType(
    "TemporalAsset",
    (_message.Message,),
    {
        "DESCRIPTOR": _TEMPORALASSET,
        "__module__": "google.cloud.asset_v1p2beta1.proto.assets_pb2",
        "__doc__": """Temporal asset. In addition to the asset, the temporal
  asset includes the status of the asset and valid from and to time of it.
  
  
  Attributes:
      window:
          The time window when the asset data and state was observed.
      deleted:
          If the asset is deleted or not.
      asset:
          Asset.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.TemporalAsset)
    },
)
_sym_db.RegisterMessage(TemporalAsset)

TimeWindow = _reflection.GeneratedProtocolMessageType(
    "TimeWindow",
    (_message.Message,),
    {
        "DESCRIPTOR": _TIMEWINDOW,
        "__module__": "google.cloud.asset_v1p2beta1.proto.assets_pb2",
        "__doc__": """A time window of (start_time, end_time].
  
  
  Attributes:
      start_time:
          Start time of the time window (exclusive).
      end_time:
          End time of the time window (inclusive). Current timestamp if
          not specified.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.TimeWindow)
    },
)
_sym_db.RegisterMessage(TimeWindow)

Asset = _reflection.GeneratedProtocolMessageType(
    "Asset",
    (_message.Message,),
    {
        "DESCRIPTOR": _ASSET,
        "__module__": "google.cloud.asset_v1p2beta1.proto.assets_pb2",
        "__doc__": """Cloud asset. This includes all Google Cloud Platform
  resources, Cloud IAM policies, and other non-GCP assets.
  
  
  Attributes:
      name:

          The full name of the asset. For example:
          ``//compute.googleapis.com/projects/my_project_123/zones/zone1/instances/instance1``.
          See https://cloud.google.com/apis/design/resource_names#full_resource_name
          for more information.
      asset_type:
          Type of the asset. Example: “compute.googleapis.com/Disk”.
      resource:
          Representation of the resource.
      iam_policy:
          Representation of the actual Cloud IAM policy set on a cloud
          resource. For each resource, there must be at most one Cloud
          IAM policy set on it.
      ancestors:
          Asset’s ancestry path in Cloud Resource Manager (CRM)
          hierarchy, represented as a list of relative resource names.
          Ancestry path starts with the closest CRM ancestor and ends at
          root. If the asset is a CRM project/folder/organization, this
          starts from the asset itself.  Example: [“projects/123456789”,
          “folders/5432”, “organizations/1234”]
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.Asset)
    },
)
_sym_db.RegisterMessage(Asset)

Resource = _reflection.GeneratedProtocolMessageType(
    "Resource",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESOURCE,
        "__module__": "google.cloud.asset_v1p2beta1.proto.assets_pb2",
        "__doc__": """Representation of a cloud resource.
  
  
  Attributes:
      version:
          The API version. Example: “v1”.
      discovery_document_uri:
          The URL of the discovery document containing the resource’s
          JSON schema. For example: ``"https://www.googleapis.com/discov
          ery/v1/apis/compute/v1/rest"``. It will be left unspecified
          for resources without a discovery-based API, such as Cloud
          Bigtable.
      discovery_name:
          The JSON schema name listed in the discovery document.
          Example: “Project”. It will be left unspecified for resources
          (such as Cloud Bigtable) without a discovery-based API.
      resource_url:
          The REST URL for accessing the resource. An HTTP GET operation
          using this URL returns the resource itself. Example:
          ``https://cloudresourcemanager.googleapis.com/v1/projects/my-
          project-123``. It will be left unspecified for resources
          without a REST API.
      parent:
          The full name of the immediate parent of this resource. See
          `Resource Names <https://cloud.google.com/apis/design/resource
          _names#full_resource_name>`__ for more information.  For GCP
          assets, it is the parent resource defined in the `Cloud IAM
          policy hierarchy <https://cloud.google.com/iam/docs/overview#p
          olicy_hierarchy>`__. For example: ``"//cloudresourcemanager.go
          ogleapis.com/projects/my_project_123"``.  For third-party
          assets, it is up to the users to define.
      data:
          The content of the resource, in which some sensitive fields
          are scrubbed away and may not be present.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.Resource)
    },
)
_sym_db.RegisterMessage(Resource)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


from __future__ import absolute_import
import sys

from google.api_core.protobuf_helpers import get_messages

from google.cloud.asset_v1p2beta1.proto import asset_service_pb2
from google.protobuf import empty_pb2
from google.protobuf import field_mask_pb2


_shared_modules = [empty_pb2, field_mask_pb2]

_local_modules = [asset_service_pb2]

names = []

for module in _shared_modules:  # pragma: NO COVER
    for name, message in get_messages(module).items():
        setattr(sys.modules[__name__], name, message)
        names.append(name)
for module in _local_modules:
    for name, message in get_messages(module).items():
        message.__module__ = "google.cloud.asset_v1p2beta1.types"
        setattr(sys.modules[__name__], name, message)
        names.append(name)


__all__ = tuple(sorted(names))



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


from __future__ import absolute_import
import sys
import warnings

from google.cloud.asset_v1beta1 import types
from google.cloud.asset_v1beta1.gapic import asset_service_client
from google.cloud.asset_v1beta1.gapic import enums


if sys.version_info[:2] == (2, 7):
    message = (
        "A future version of this library will drop support for Python 2.7."
        "More details about Python 2 support for Google Cloud Client Libraries"
        "can be found at https://cloud.google.com/python/docs/python2-sunset/"
    )
    warnings.warn(message, DeprecationWarning)


class AssetServiceClient(asset_service_client.AssetServiceClient):
    __doc__ = asset_service_client.AssetServiceClient.__doc__
    enums = enums


__all__ = ("enums", "types", "AssetServiceClient")



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Wrappers for protocol buffer enum types."""

import enum


class ContentType(enum.IntEnum):
    """
    Asset content type.

    Attributes:
      CONTENT_TYPE_UNSPECIFIED (int): Unspecified content type.
      RESOURCE (int): Resource metadata.
      IAM_POLICY (int): The actual IAM policy set on a resource.
    """

    CONTENT_TYPE_UNSPECIFIED = 0
    RESOURCE = 1
    IAM_POLICY = 2


class NullValue(enum.IntEnum):
    """
    ``NullValue`` is a singleton enumeration to represent the null value
    for the ``Value`` type union.

    The JSON representation for ``NullValue`` is JSON ``null``.

    Attributes:
      NULL_VALUE (int): Null value.
    """

    NULL_VALUE = 0



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.cloud.asset_v1beta1.proto import (
    asset_service_pb2 as google_dot_cloud_dot_asset__v1beta1_dot_proto_dot_asset__service__pb2,
)
from google.longrunning import (
    operations_pb2 as google_dot_longrunning_dot_operations__pb2,
)


class AssetServiceStub(object):
    """Asset service definition.
  """

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.ExportAssets = channel.unary_unary(
            "/google.cloud.asset.v1beta1.AssetService/ExportAssets",
            request_serializer=google_dot_cloud_dot_asset__v1beta1_dot_proto_dot_asset__service__pb2.ExportAssetsRequest.SerializeToString,
            response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
        self.BatchGetAssetsHistory = channel.unary_unary(
            "/google.cloud.asset.v1beta1.AssetService/BatchGetAssetsHistory",
            request_serializer=google_dot_cloud_dot_asset__v1beta1_dot_proto_dot_asset__service__pb2.BatchGetAssetsHistoryRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_asset__v1beta1_dot_proto_dot_asset__service__pb2.BatchGetAssetsHistoryResponse.FromString,
        )


class AssetServiceServicer(object):
    """Asset service definition.
  """

    def ExportAssets(self, request, context):
        """Exports assets with time and resource types to a given Cloud Storage
    location. The output format is newline-delimited JSON.
    This API implements the
    [google.longrunning.Operation][google.longrunning.Operation] API allowing
    you to keep track of the export.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def BatchGetAssetsHistory(self, request, context):
        """Batch gets the update history of assets that overlap a time window.
    For RESOURCE content, this API outputs history with asset in both
    non-delete or deleted status.
    For IAM_POLICY content, this API outputs history when the asset and its
    attached IAM POLICY both exist. This can create gaps in the output history.
    If a specified asset does not exist, this API returns an INVALID_ARGUMENT
    error.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_AssetServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ExportAssets": grpc.unary_unary_rpc_method_handler(
            servicer.ExportAssets,
            request_deserializer=google_dot_cloud_dot_asset__v1beta1_dot_proto_dot_asset__service__pb2.ExportAssetsRequest.FromString,
            response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
        ),
        "BatchGetAssetsHistory": grpc.unary_unary_rpc_method_handler(
            servicer.BatchGetAssetsHistory,
            request_deserializer=google_dot_cloud_dot_asset__v1beta1_dot_proto_dot_asset__service__pb2.BatchGetAssetsHistoryRequest.FromString,
            response_serializer=google_dot_cloud_dot_asset__v1beta1_dot_proto_dot_asset__service__pb2.BatchGetAssetsHistoryResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.cloud.asset.v1beta1.AssetService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.cloud.asset_v1p4beta1.proto import (
    asset_service_pb2 as google_dot_cloud_dot_asset__v1p4beta1_dot_proto_dot_asset__service__pb2,
)
from google.longrunning import (
    operations_pb2 as google_dot_longrunning_dot_operations__pb2,
)


class AssetServiceStub(object):
    """Asset service definition.
  """

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.AnalyzeIamPolicy = channel.unary_unary(
            "/google.cloud.asset.v1p4beta1.AssetService/AnalyzeIamPolicy",
            request_serializer=google_dot_cloud_dot_asset__v1p4beta1_dot_proto_dot_asset__service__pb2.AnalyzeIamPolicyRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_asset__v1p4beta1_dot_proto_dot_asset__service__pb2.AnalyzeIamPolicyResponse.FromString,
        )
        self.ExportIamPolicyAnalysis = channel.unary_unary(
            "/google.cloud.asset.v1p4beta1.AssetService/ExportIamPolicyAnalysis",
            request_serializer=google_dot_cloud_dot_asset__v1p4beta1_dot_proto_dot_asset__service__pb2.ExportIamPolicyAnalysisRequest.SerializeToString,
            response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )


class AssetServiceServicer(object):
    """Asset service definition.
  """

    def AnalyzeIamPolicy(self, request, context):
        """Analyzes IAM policies based on the specified request. Returns
    a list of [IamPolicyAnalysisResult][google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult] matching the request.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ExportIamPolicyAnalysis(self, request, context):
        """Exports IAM policy analysis based on the specified request. This API
    implements the [google.longrunning.Operation][google.longrunning.Operation] API allowing you to keep
    track of the export. The metadata contains the request to help callers to
    map responses to requests.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_AssetServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "AnalyzeIamPolicy": grpc.unary_unary_rpc_method_handler(
            servicer.AnalyzeIamPolicy,
            request_deserializer=google_dot_cloud_dot_asset__v1p4beta1_dot_proto_dot_asset__service__pb2.AnalyzeIamPolicyRequest.FromString,
            response_serializer=google_dot_cloud_dot_asset__v1p4beta1_dot_proto_dot_asset__service__pb2.AnalyzeIamPolicyResponse.SerializeToString,
        ),
        "ExportIamPolicyAnalysis": grpc.unary_unary_rpc_method_handler(
            servicer.ExportIamPolicyAnalysis,
            request_deserializer=google_dot_cloud_dot_asset__v1p4beta1_dot_proto_dot_asset__service__pb2.ExportIamPolicyAnalysisRequest.FromString,
            response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.cloud.asset.v1p4beta1.AssetService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
